# GithubStat
**A Simple Github User Statistics Meter based on Github-API.**

[![Author](https://img.shields.io/badge/Author-HTR--TECH-blue)](https://github.com/htr-tech)
[![Opensource](https://img.shields.io/badge/Open%20Source-Yes-green)](#)
[![Version](https://badge.fury.io/py/GithubStat.svg)](https://badge.fury.io/py/GithubStat)
[![Python Version](https://img.shields.io/pypi/pyversions/GithubStat.svg)](https://pypi.org/project/GithubStat)
[![Total Downloads](https://pepy.tech/badge/GithubStat)](https://pepy.tech/project/GithubStat)
[![Monthly Downloads](https://pepy.tech/badge/GithubStat/month)](https://pepy.tech/project/GithubStat/month)

### Installation :

- **Install GithubStat via Pypi :**
```
$ pip install GithubStat
```
- Now simply Type 
```
$ GithubStat <github-username>
```
- **Use it via console :**
```python
>>> from GithubStat.__init__ import stats
>>> stats('htr-tech')

[-] Username  : htr-tech

[-] Name      : Tahmid Rayat
[-] Followers : 1969
[-] Following : 12
......
```
- **Install GithubStat via Github :**
```
$ git clone https://github.com/htr-tech/GithubStat.git
$ cd GithubStat
$ python setup.py install
$ GithubStat <github-username>
```

***Copyright (c) 2021 Tahmid Rayat Under [MIT LICENSE](https://github.com/htr-tech/GithubStat/blob/master/LICENSE#L1)***

### *📡 Get in Touch :*
[![Github](https://img.shields.io/badge/Github-525252?style=for-the-badge&logo=github)](https://github.com/htr-tech)
[![Facebook](https://img.shields.io/badge/Facebook-3b5998?style=for-the-badge&logo=facebook)](https://fb.com/tahmid.rayat.official)
[![Instagram](https://img.shields.io/badge/Instagram-8a3ab9?style=for-the-badge&logo=instagram)](https://www.instagram.com/tahmid.rayat)


